import { useRef, useEffect, useState } from 'react'
import { FiEdit3, FiTrash, FiChevronDown } from 'react-icons/fi'
import { TbEraser } from 'react-icons/tb'
import './Notes.sass'

const Notes = () => {
  const canvasRef = useRef(null)
  const [isDrawing, setIsDrawing] = useState(false)
  const [tool, setTool] = useState('pen') // 'pen' or 'eraser'
  const [penColor, setPenColor] = useState('#2d3748')
  const [showColorPicker, setShowColorPicker] = useState(false)

  const colors = [
    '#2d3748', // Dark gray
    '#000000', // Black
    '#e53e3e', // Red
    '#3182ce', // Blue
    '#38a169', // Green
    '#d69e2e', // Yellow
    '#805ad5', // Purple
    '#dd6b20', // Orange
    '#e91e63', // Pink
    '#00acc1'  // Cyan
  ]

  useEffect(() => {
    const canvas = canvasRef.current
    const ctx = canvas.getContext('2d')
    
    // Set canvas size
    const resizeCanvas = () => {
      const container = canvas.parentElement
      const imageData = ctx.getImageData(0, 0, canvas.width, canvas.height)
      
      canvas.width = container.clientWidth
      canvas.height = container.clientHeight
      
      // Set drawing properties
      ctx.lineCap = 'round'
      ctx.lineJoin = 'round'
      ctx.imageSmoothingEnabled = true
      
      // Restore canvas content after resize
      ctx.putImageData(imageData, 0, 0)
      
      // Load saved canvas data
      loadCanvasFromStorage()
    }
    
    resizeCanvas()
    window.addEventListener('resize', resizeCanvas)
    
    return () => window.removeEventListener('resize', resizeCanvas)
  }, [])

  const saveCanvasToStorage = () => {
    const canvas = canvasRef.current
    const dataURL = canvas.toDataURL()
    localStorage.setItem('notes-canvas', dataURL)
  }

  const loadCanvasFromStorage = () => {
    const canvas = canvasRef.current
    const ctx = canvas.getContext('2d')
    const savedData = localStorage.getItem('notes-canvas')
    
    if (savedData) {
      const img = new Image()
      img.onload = () => {
        ctx.clearRect(0, 0, canvas.width, canvas.height)
        ctx.drawImage(img, 0, 0)
      }
      img.src = savedData
    }
  }

  const startDrawing = (e) => {
    setIsDrawing(true)
    const canvas = canvasRef.current
    const ctx = canvas.getContext('2d')
    const rect = canvas.getBoundingClientRect()
    
    const x = e.clientX - rect.left
    const y = e.clientY - rect.top
    
    ctx.beginPath()
    ctx.moveTo(x, y)
  }

  const draw = (e) => {
    if (!isDrawing) return
    
    const canvas = canvasRef.current
    const ctx = canvas.getContext('2d')
    const rect = canvas.getBoundingClientRect()
    
    const x = e.clientX - rect.left
    const y = e.clientY - rect.top
    
    if (tool === 'pen') {
      ctx.globalCompositeOperation = 'source-over'
      ctx.strokeStyle = penColor
      ctx.lineWidth = 3
      ctx.lineTo(x, y)
      ctx.stroke()
    } else if (tool === 'eraser') {
      ctx.globalCompositeOperation = 'destination-out'
      ctx.lineWidth = 40 // Increased eraser size
      ctx.lineTo(x, y)
      ctx.stroke()
    }
  }

  const stopDrawing = () => {
    setIsDrawing(false)
    // Save canvas state after drawing
    saveCanvasToStorage()
  }

  const clearCanvas = () => {
    const canvas = canvasRef.current
    const ctx = canvas.getContext('2d')
    ctx.clearRect(0, 0, canvas.width, canvas.height)
    // Clear saved state
    localStorage.removeItem('notes-canvas')
  }

  return (
    <div className="notes-page">
      <div className="notes-container">
        {/* Toolbar */}
        <div className="notes-toolbar">
          <div className="pen-tool-group">
            <button
              className={`tool-button ${tool === 'pen' ? 'active' : ''}`}
              onClick={() => setTool('pen')}
              title="Stift"
              style={{ backgroundColor: tool === 'pen' ? penColor + '20' : undefined }}
            >
              <FiEdit3 style={{ color: tool === 'pen' ? penColor : undefined }} />
            </button>
            <button
              className="color-picker-button"
              onClick={() => setShowColorPicker(!showColorPicker)}
              title="Farbe wählen"
              style={{ backgroundColor: penColor }}
            >
              <FiChevronDown />
            </button>
            {showColorPicker && (
              <div className="color-picker-popover">
                <div className="color-grid">
                  {colors.map((color) => (
                    <button
                      key={color}
                      className={`color-option ${penColor === color ? 'active' : ''}`}
                      style={{ backgroundColor: color }}
                      onClick={() => {
                        setPenColor(color)
                        setShowColorPicker(false)
                      }}
                      title={`Farbe: ${color}`}
                    />
                  ))}
                </div>
              </div>
            )}
          </div>
          
          <button
            className={`tool-button ${tool === 'eraser' ? 'active' : ''}`}
            onClick={() => setTool('eraser')}
            title="Radiergummi"
          >
            <TbEraser />
          </button>
          
          <button
            className="tool-button clear-button"
            onClick={clearCanvas}
            title="Alles löschen"
          >
            <FiTrash />
          </button>
        </div>

        {/* Canvas Container */}
        <div className="canvas-container">
          <canvas
            ref={canvasRef}
            className="drawing-canvas"
            onMouseDown={startDrawing}
            onMouseMove={draw}
            onMouseUp={stopDrawing}
            onMouseLeave={stopDrawing}
          />
        </div>
      </div>
    </div>
  )
}

export default Notes
